# Release Notes

All notable changes to this project are documented in this file. It was automatically generated with 
the [changelog-from-release](https://github.com/rhysd/changelog-from-release) tool.

<a id="v0.1.0"></a>
# [v0.1.0](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.1.0) - 2025-09-18

## What's Changed
* :sparkles: first rudementary API documentation by [@enryH](https://github.com/enryH) in [#9](https://github.com/Multiomics-Analytics-Group/vuecore/pull/9)
* Add logo by [@sayalaruano](https://github.com/sayalaruano) in [#10](https://github.com/Multiomics-Analytics-Group/vuecore/pull/10)
* Refactor vuecore library with an initial example for scatter plot by [@sayalaruano](https://github.com/sayalaruano) in [#11](https://github.com/Multiomics-Analytics-Group/vuecore/pull/11)
* Remove_python_restriction by [@enryH](https://github.com/enryH) in [#15](https://github.com/Multiomics-Analytics-Group/vuecore/pull/15)
* :wrench:  set up sync of notebooks to py:percent format (manually) by [@enryH](https://github.com/enryH) in [#17](https://github.com/Multiomics-Analytics-Group/vuecore/pull/17)
* Update logo by [@sayalaruano](https://github.com/sayalaruano) in [#19](https://github.com/Multiomics-Analytics-Group/vuecore/pull/19)
* Update scatter plot to align with the Plotly API by [@sayalaruano](https://github.com/sayalaruano) in [#21](https://github.com/Multiomics-Analytics-Group/vuecore/pull/21)
* ✨ Feat: Add scripts, test, and example for line plot by [@sayalaruano](https://github.com/sayalaruano) in [#20](https://github.com/Multiomics-Analytics-Group/vuecore/pull/20)
* 🧑‍💻 Dev: add PR templates for general contributions and add new plots by [@sayalaruano](https://github.com/sayalaruano) in [#22](https://github.com/Multiomics-Analytics-Group/vuecore/pull/22)
* Update readme, license, and contributing by [@sayalaruano](https://github.com/sayalaruano) in [#24](https://github.com/Multiomics-Analytics-Group/vuecore/pull/24)
* :wrench: configure the plotly renderer on Read The Docs by [@enryH](https://github.com/enryH) in [#18](https://github.com/Multiomics-Analytics-Group/vuecore/pull/18)
* ✨ Feat: Add scripts, test, and example for bar plot  by [@sayalaruano](https://github.com/sayalaruano) in [#26](https://github.com/Multiomics-Analytics-Group/vuecore/pull/26)
* File formats enum by [@sayalaruano](https://github.com/sayalaruano) in [#27](https://github.com/Multiomics-Analytics-Group/vuecore/pull/27)
* ✨ Feat: Add scripts, test, and example for box plot by [@sayalaruano](https://github.com/sayalaruano) in [#30](https://github.com/Multiomics-Analytics-Group/vuecore/pull/30)
* Add script to split readme and organize documentation by [@sayalaruano](https://github.com/sayalaruano) in [#29](https://github.com/Multiomics-Analytics-Group/vuecore/pull/29)
* ✅ Enable pytest on github action by [@sayalaruano](https://github.com/sayalaruano) in [#28](https://github.com/Multiomics-Analytics-Group/vuecore/pull/28)
* ✨ Create Base Plotly Schema by [@sayalaruano](https://github.com/sayalaruano) in [#31](https://github.com/Multiomics-Analytics-Group/vuecore/pull/31)
* ✨Factory function for user-facing plot functions by [@sayalaruano](https://github.com/sayalaruano) in [#33](https://github.com/Multiomics-Analytics-Group/vuecore/pull/33)
* ✨Factory function for building plotly plot functions by [@sayalaruano](https://github.com/sayalaruano) in [#34](https://github.com/Multiomics-Analytics-Group/vuecore/pull/34)
* 📝 Docs: Update contributing guidelines by [@sayalaruano](https://github.com/sayalaruano) in [#37](https://github.com/Multiomics-Analytics-Group/vuecore/pull/37)
* ✨ Feat: Add scripts, test, and example for violin plot by [@sayalaruano](https://github.com/sayalaruano) in [#39](https://github.com/Multiomics-Analytics-Group/vuecore/pull/39)
* ✨ Feat: Add scripts, test, and example for histogram plot by [@sayalaruano](https://github.com/sayalaruano) in [#41](https://github.com/Multiomics-Analytics-Group/vuecore/pull/41)
* 📝 Docs(src/vuecore/README.md): Add Readme to explain the project structure and workflow by [@sayalaruano](https://github.com/sayalaruano) in [#42](https://github.com/Multiomics-Analytics-Group/vuecore/pull/42)

## New Contributors
* [@sayalaruano](https://github.com/sayalaruano) made their first contribution in [#10](https://github.com/Multiomics-Analytics-Group/vuecore/pull/10)

**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.5...v0.1.0

[Changes][v0.1.0]


<a id="v0.0.5"></a>
# [v0.0.5](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.0.5) - 2025-01-31

## What's Changed
* :truck: move PCA plot from acore normalization example by [@enryH](https://github.com/enryH) in [#8](https://github.com/Multiomics-Analytics-Group/vuecore/pull/8)


**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.4...v0.0.5

[Changes][v0.0.5]


<a id="v0.0.4"></a>
# [v0.0.4](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.0.4) - 2025-01-29

## What's Changed
* :truck: add functionality from acore by [@enryH](https://github.com/enryH) in [#7](https://github.com/Multiomics-Analytics-Group/vuecore/pull/7)


**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.3...v0.0.4

[Changes][v0.0.4]


<a id="v0.0.3"></a>
# [v0.0.3](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.0.3) - 2024-12-18

- fix import error (file was not renamed correctly)
**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.2...v0.0.3

[Changes][v0.0.3]


<a id="v0.0.2"></a>
# [v0.0.2](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.0.2) - 2024-12-17

Prepare for use in acore api examples: format and fix imports

## What's Changed
* :format: format with black by [@enryH](https://github.com/enryH) in [#5](https://github.com/Multiomics-Analytics-Group/vuecore/pull/5)
* Fix imports by [@enryH](https://github.com/enryH) in [#3](https://github.com/Multiomics-Analytics-Group/vuecore/pull/3)


**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.1...v0.0.2

[Changes][v0.0.2]


<a id="v0.0.1"></a>
# [v0.0.1](https://github.com/Multiomics-Analytics-Group/vuecore/releases/tag/v0.0.1) - 2024-11-29

First release to have a development version on PyPI. All plots and their dependencies needs to be tested.

## What's Changed
* Mk pkg by [@enryH](https://github.com/enryH) in [#1](https://github.com/Multiomics-Analytics-Group/vuecore/pull/1)

## New Contributors
* [@enryH](https://github.com/enryH) made their first contribution in [#1](https://github.com/Multiomics-Analytics-Group/vuecore/pull/1)

**Full Changelog**: https://github.com/Multiomics-Analytics-Group/vuecore/commits/v0.0.1

[Changes][v0.0.1]


[v0.1.0]: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.5...v0.1.0
[v0.0.5]: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.4...v0.0.5
[v0.0.4]: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.3...v0.0.4
[v0.0.3]: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.2...v0.0.3
[v0.0.2]: https://github.com/Multiomics-Analytics-Group/vuecore/compare/v0.0.1...v0.0.2
[v0.0.1]: https://github.com/Multiomics-Analytics-Group/vuecore/tree/v0.0.1

<!-- Generated by https://github.com/rhysd/changelog-from-release v3.9.0 -->